@@ -92,7 +92,7 @@ def divide(obj1, obj2, as_float=False):
         return sec1 / sec2
     else:
         if as_float:
-            assert None, "float=True is inappropriate when dividing timedelta by a number."
+            assert None, "as_float=True is inappropriate when dividing timedelta by a number."
         secs = sec1 / obj2
         if isinstance(secs, Decimal):
             secs = float(secs)
@@ -121,7 +121,7 @@ def percentage(obj1, obj2):
     assert isinstance(obj1, datetime.timedelta), "First argument must be a timedelta."
     assert isinstance(obj2, datetime.timedelta), "Second argument must be a timedelta."
     
-    return divide(obj1 * 100, obj2, float=True)
+    return divide(obj1 * 100, obj2, as_float=True)
 
 def multiply(obj, val):
     """
@@ -176,9 +176,18 @@ def round_to_nearest(obj, timedelta):
     else:
         return result
 
-def decimal_hours(timedelta):
+def decimal_hours(timedelta, decimal_places=None):
     """
     Return a decimal value of the number of hours that this timedelta
     object refers to.
     """
-    return Decimal(timedelta.days*24) + Decimal(timedelta.seconds) / 3600
\ No newline at end of file
+    hours = Decimal(timedelta.days*24) + Decimal(timedelta.seconds) / 3600
+    if decimal_places:
+        return hours.quantize(Decimal(str(10**-decimal_places)))
+    return hours
+
+def week_containing(date):
+    if date.weekday():
+        date -= datetime.timedelta(date.weekday())
+    
+    return date, date + datetime.timedelta(6)
